#
# spec file for package partitionmanager
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%bcond_without released
Name:           partitionmanager
Version:        21.12.3
Release:        bp154.1.33
Summary:        Easily manage disks, partitions and file systems on your KDE Desktop
License:        GPL-3.0-or-later
Group:          Productivity/File utilities
URL:            https://apps.kde.org/partitionmanager
Source:         https://download.kde.org/stable/release-service/%{version}/src/%{name}-%{version}.tar.xz
%if %{with released}
Source1:        https://download.kde.org/stable/release-service/%{version}/src/%{name}-%{version}.tar.xz.sig
Source2:        applications.keyring
%endif
BuildRequires:  extra-cmake-modules >= 5.73
%if 0%{?suse_version} <= 1500
BuildRequires:  gcc10-c++
%endif
BuildRequires:  kf5-filesystem
BuildRequires:  update-desktop-files
BuildRequires:  cmake(KF5Config)
BuildRequires:  cmake(KF5ConfigWidgets)
BuildRequires:  cmake(KF5CoreAddons)
BuildRequires:  cmake(KF5Crash)
BuildRequires:  cmake(KF5DBusAddons)
BuildRequires:  cmake(KF5DocTools)
BuildRequires:  cmake(KF5I18n)
BuildRequires:  cmake(KF5JobWidgets)
BuildRequires:  cmake(KF5KIO)
BuildRequires:  cmake(KF5WidgetsAddons)
BuildRequires:  cmake(KF5XmlGui)
# Update for each minor change
BuildRequires:  cmake(KPMcore) >= 21.12
BuildRequires:  cmake(Qt5Core) >= 5.14.0
BuildRequires:  cmake(Qt5Gui)
BuildRequires:  cmake(Qt5Widgets)
Obsoletes:      partitionmanager5 < %{version}
Provides:       partitionmanager5 = %{version}

%description
This software allows you to manage your disks, partitions and
file systems: Create, resize, delete, copy, backup and restore
partitions with a large number of supported file systems (ext2/3,
reiserfs, NTFS, FAT32 and more). It makes use of external
programs to get its job done, so you might have to install
additional software (preferably packages from your distribution)
to make use of all features and get full support for all file
systems.

%lang_package

%prep
%autosetup -p1

%build
%cmake_kf5 -d build
%cmake_build

%install
%kf5_makeinstall -C build
%if %{with released}
  %find_lang partitionmanager
  %{kf5_find_htmldocs}
%endif

%suse_update_desktop_file org.kde.partitionmanager

%files
%doc README.md
%license LICENSES/*
%doc %lang(en) %{_kf5_htmldir}/en/partitionmanager/
%{_kf5_applicationsdir}/org.kde.partitionmanager.desktop
%{_kf5_appstreamdir}/org.kde.partitionmanager.appdata.xml
%{_kf5_bindir}/partitionmanager
%{_kf5_configkcfgdir}/partitionmanager.kcfg
%{_kf5_iconsdir}/hicolor/*/apps/partitionmanager.svg
%{_kf5_kxmlguidir}/partitionmanager/

%if %{with released}
%files lang -f partitionmanager.lang
%endif

%changelog
* Fri Mar 11 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update license to GPL-3.0-or-later.
* Wed Mar  2 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.12.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.12.3/
- No code change since 21.12.2
* Sat Feb  5 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.12.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.12.2/
- No code change since 21.12.1
* Thu Jan 13 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.12.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.12.1/
- Changes since 21.08.3:
  * Bump minimal cmake version to 3.16
* Sat Nov 13 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.08.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.08.3/
- No code change since 21.08.1
* Mon Sep  6 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.08.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.08.1
- No code change since 21.08.0
* Fri Aug  6 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.08.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/21.08.0
- Changes since 21.04.2:
  * Switch default file system to Btrfs (kde#438376)
* Fri Jun 25 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.04.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.04.2
- No code change since 21.04.1
* Wed May 19 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.04.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.04.1
- Changes since 21.04.0:
  * Fix appstream link
* Tue Apr 20 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.04.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/21.04
* Tue Oct 27 2020 wbauer@tmo.at
- Update to 4.2.0
  * KAuth helper replaced with pure PolkitQt1 helper
  * KDE Partition Manager (including KPMcore library) is now fully
    REUSE 3.0 compliant
  * Support for partitions with unknown file system
  * Fixed and improved mount point and /etc/fstab handling
  * Fixed a crash that was present for a long time but hard to
    reproduce reliably
  * KPMcore gained support for GPT partition attributes (It is not
    yet wired in KDE Partition Manager)
  * KPMcore has more support for setting GPT partition label and
    UUID (Again, not yet wired in KDE Partition Manager)
  * Port away from various deprecated Qt/KDE methods
  * Workaround bad JSON output from sfdisk (will be fixed in
    util-linux 2.37).
  * Import partition flags when importing partition table
  * Apply colour scheme to secondary (MBR logical) partitions
* Mon Feb 10 2020 wbauer@tmo.at
- Update to 4.1.0
  * Support for Minix file system
* Fri May 24 2019 wbauer@tmo.at
- Update to 4.0.0
  * Ported to KAuth to let the GUI run as unprivileged user
  * KPMcore backend was ported away from libparted to sfdisk (part
    of util-linux)
  * Ported S.M.A.R.T. code away from unmaintained libatasmart to
    smartmontools
  * Better support for LUKS2
  * Detection support for Apple's APFS filesystem and Microsoft's
    Bitlocker
  * Many of the KPMcore classes now use d-pointers, which in the
    future releases will help us to maintain binary compatibility
    (ABI) a bit better
  * Use more modern C++ features
  * Some bugfixes, in particular related to LVM
* Tue Oct 16 2018 Fabian Vogt <fabian@ritter-vogt.de>
- Use %%license
- Move en doc file from -lang into the main package
* Mon Jan  8 2018 wbauer@tmo.at
- Update to 3.3.1
  * Fix one crash when resizing LVM logical volumes
* Fri Dec 15 2017 wbauer@tmo.at
- Update to 3.3.0
  * some improvements for Btrfs, F2FS, NTFS file systems
  * first bits of new LUKS2 on-disk format support, now KDE
    Partition Manager can display LUKS2 labels
* Sun Oct  8 2017 wbauer@tmo.at
- Update to 3.2.1
  * Fix a broken QRegularExpression in LVM VG name validator.
* Sun Oct  1 2017 wbauer@tmo.at
- Update to 3.2.0
  * Added support for UDF file system (this change requires
    util-linux 2.30). While adding support for UDF, the following
    general improvements were made:
    + KPM now supports setting label for file systems where it can
    only be done during initial formating (e.g. nilfs2 or udf)
    + File system label widget (QLineEdit) now validates its input
    for certain file systems (at the moment only FAT and UDF),
    not just maximum label length.
  * Detection support for ISO9660 file system
* Wed Sep  6 2017 wbauer@tmo.at
- Update to 3.1.2
  * Add back translated docs that were missing in 3.1.1
- Update to 3.1.1
  * Fix a crash when clicking cancel in ApplyProgressDialog.
    (kde#384348)
* Mon Jun 19 2017 wbauer@tmo.at
- Update to 3.1.0
  * Workaround for a change/bug (see kde#380974) in KNotifications
    5.33 that in some cases caused KMessageBoxes to hang for a few
    seconds.
- Adjust build requirements, Qt 5.7.0 and Frameworks 5.31.0 are
  needed now
- Use %%kf5_find_htmldocs to generate the documentation file list
* Sat Jan  7 2017 wbauer@tmo.at
- Update to 3.0.1
* Mon Dec 19 2016 fabian@ritter-vogt.de
- Update to 3.0.0
- Sync with KDE:Unstable:Extra
- Update license to GPL-3.0
* Fri Aug 26 2016 wbauer@tmo.at
- Update to 2.2.1
- Adjust build requirements
- Add update-appstream-path-to-use-ECM-variable.patch to install
  the appstream data to the right place and use the
  %%{kf5_appstreamdir} macro for the file list
* Sun Jun 19 2016 jacobwinski@gmail.com
- Update to 2.2.0.
- Update kpmcore version requirement in spec file.
* Sun Apr  3 2016 hrvoje.senjan@gmail.com
- Update to 2.1.0
* Mon Jan 18 2016 tittiatcoke@gmail.com
- Update to 2.0.0
  * Split out the kpmcore library from the main package
* Fri May  1 2015 asterios.dramis@gmail.com
- Added new build requirement kwindowsystem-devel.
- Removed unneeded build requirement fdupes.
* Mon Apr  6 2015 hrvoje.senjan@gmail.com
- Update to 1.2.1:
  * Port to KDE Frameworks is complete
- Drop the udisks2 cmake option, no longer needed
* Thu Jul 10 2014 hrvoje.senjan@gmail.com
- Update to 1.1.0
  * Most important changes in this release are support for Btrfs
    file system and GPT partition table. This release also adds
    support for exFAT, NILFS 2 and very basic support for ZFS,
    encrypted LUKS containers and LVM2 physical volumes. There
    are some nice GUI improvements as well, partition widget
    design was improved by Hugo Pereira Da Costa.
- Enable UDisks2 backend
- Minor spec cleanup
* Tue Nov  5 2013 dmitry_r@opensuse.org
- Add partitionmanager-lang as recommended dependence
* Mon Oct  4 2010 bitshuffler@opensuse.org
- Updated to 1.0.3
  * Make sure available and used capacity are not printed in a partition's
    properties dialog if they are not known
  * Make sure fsck.msdos does not want to modify a file system when it is being
    called to read the file system usage
  * Warn the user when trying to overwrite an existing partition with another or
    an image file
  * Clear the clipboard if undoing an operation deleted the partition that was in it
  * Keep the current UUID when resizing a swap partition
  * Fix the build by explicitly linking the partition manager executable against
    the KDE libs it uses
  * Do not allow pasting a source partition on a bigger target partition when the
    source partition's file system cannot be grown to fill the target partition
* Sun Jul 25 2010 bitshuffler@opensuse.org
- Updated to 1.0.2
  * Copy a file system's UUID to the copied file system when creating a file
    system from another one.
  * Implement a workaround for a libparted bug that makes it sometimes fail to
    commit changes to the OS in versions earlier than 2.2.
  * Update the partition's file system and re-check for constraints if the
    partition's role is changed in the "Create New Partition" dialog. This fixes
    a bug where the user was not able to grow an extended partition if he'd
    previously selected a file system that cannot grow beyond a certain size.
  * Always use the correct icons in modified ok/cancel buttons in dialogs and
    message boxes
  * Fix a crash when operations to create, resize and delete an extended
    partitions where incorrectly merged into one (bug 232092)
* Sun Jan 10 2010 rwooninck@opensuse.org
- Updated to 1.0.1
  - Fix a bug that made it impossible to activate or deactivate a
    swap file system.
  - Correctly handle linux swap even with newer parted versions.
  - Ask for an administrator's password on startup so that non-KDE
    users can run the application from their launcher.
  - Use the "blkid" command as an alternative to "vol_id" if the
    latter is unavailable.
  - Do not crash when using the Oxygen style under KDE SC 4.4.
  - Do not crash when the user clicks in the partition widget with
    newer g++ versions.
  - Sort devices by name after scanning.
  - Don't disable updates for the partition widget while applying
    operations. This leads to corrupted graphics unter Qt4.6.
  - Work around a LibParted segmentation fault when the Linux Device
    Mapper is used and /dev/mapper has non-existing entries.
  - The above also works around a LibParted problem when the BIOS has
    a floppy drive configured but none is actually present.
  - Set item height in the partition and devices lists to 32 pixel
    to make them look less condensed.
* Thu Oct  8 2009 bitshuffler@opensuse.org
- Updated to 1.0.0
  - Many translations heavily improved.
  - Correctly handle ext4 file systems even with patched parted 1.8.8 (and hopefully 1.8.9 too). Patch by Fatih Asici. (bug #195243)
  - Clear the partition flags for a copied partition in the preview. (bug #202346)
  - Write the new start sector to the partition's boot sector if an NTFS file system was moved or copied. (bug #202329)
* Sun Jun  7 2009 tittiatcoke@gmail.com
- Moved to KDE:KDE4:Community
* Sun Jun  7 2009 tittiatcoke@gmail.com
- moved to KDE:KDE4:Community
  + version 1.0.0beta3
  - Set the default file system in the New-Partition-dialog, don't just rely on it being the first one in the list.
  - Sort items in file system combo boxes case-insensitively.
  - Fix a bug where the total free space available could get smaller and smaller when moving an existing partition in a dialog.
  - Fix a bug that the progress information wasn't set as window title for the top level application window.
  - Speed up copying file systems (and thus moving, resizing and copying).
  - Add some basic timing output to the detailed report for copying file systems.
  - Find a file system's mount point even if it is identified by label in fstab.
  - Add support for reading file system labels from FAT16 and FAT32.
  - Fix a bug where the volume label for a linuxswap file system was lost when resizing it.
  - Make sure all interesting information shown in labels anywhere in the application is user-selectable with the mouse.
  - Display the UUID for most file systems that support it.
  - Always show the current file system in the partition properties dialog's file system combo box, even if it cannot be created, is too big or too small.
* Wed Jun  3 2009 vl@fidra.de
- new upstream version
* Wed Apr 29 2009 vl@fidra.de
- new upstream version
* Tue Jan 13 2009 vl@fidra.de
- modified for opensuse build service
* Mon Jan 12 2009 toni@links2linux.de
- update to 1.0.0beta1
* Tue Sep 23 2008 toni@links2linux.de
- update to 1.0.0alpha2
* Thu Sep 18 2008 toni@links2linux.de
- initial build for 1.0.0-Alpha1
